@@ -1,5 +1,6 @@
-from checkov.terraform.models.enums import CheckResult, CheckCategories
-from checkov.terraform.checks.resource.base_check import BaseResourceCheck
+from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+from checkov.common.util.type_forcers import force_int
 
 
 class PasswordPolicyExpiration(BaseResourceCheck):
@@ -19,7 +20,8 @@ class PasswordPolicyExpiration(BaseResourceCheck):
         """
         key = 'max_password_age'
         if key in conf.keys():
-            if conf[key][0] >= 90:
+            max_age = force_int(conf[key][0])
+            if max_age and max_age <= 90:
                 return CheckResult.PASSED
         return CheckResult.FAILED
 
